@@ -38,7 +38,10 @@ class MILOU_EXPORT SourcesModel : public QAbstractListModel
     Q_OBJECT
     Q_PROPERTY(QString queryString READ queryString WRITE setQueryString)
     Q_PROPERTY(int queryLimit READ queryLimit WRITE setQueryLimit)
-    Q_PROPERTY(QString runner READ runner WRITE setRunner)
+    Q_PROPERTY(QString runner READ runner WRITE setRunner NOTIFY runnerChanged)
+
+    Q_PROPERTY(QString runnerName READ runnerName NOTIFY runnerChanged)
+    Q_PROPERTY(QIcon runnerIcon READ runnerIcon NOTIFY runnerChanged)
 
 public:
     explicit SourcesModel(QObject* parent = 0);
@@ -47,6 +50,7 @@ public:
     enum Roles {
         TypeRole = Qt::UserRole + 1,
         SubtextRole,
+        ActionsRole,
         DuplicateRole,
         PreviewTypeRole,
         PreviewUrlRole,
@@ -62,6 +66,9 @@ public:
     QString runner() const;
     void setRunner(const QString& runner);
 
+    QString runnerName() const;
+    QIcon runnerIcon() const;
+
     QString queryString() const;
     int queryLimit() const;
 
@@ -75,6 +82,8 @@ signals:
      */
     void updateSearchTerm(const QString& text, int pos);
 
+    void runnerChanged();
+
 public slots:
     void reloadConfiguration();
     void setQueryString(const QString& str);
@@ -82,11 +91,13 @@ public slots:
     void clear();
 
     bool run(int index);
+    bool runAction(int index, int actionIndex);
 
     Q_INVOKABLE QString getType(int index) const {
         return data(createIndex(index, 0), TypeRole).toString();
     }
 
+    Q_INVOKABLE QMimeData *getMimeData(int index) const;
 
 private slots:
     void slotMatchesChanged(const QList<Plasma::QueryMatch>& list);
